Untitled Document

General information | Degree information | Name
--- | --- | ---
Major | Gender | English | Japanese | Calculus | Geometry
Student01 | Languages | male | 80 | 70 | 75 | 80%
Student02 | Mathematics | male | 90 | 88 | 100 | 90%
Student03 | Languages | female | 85 | 95 | 80 | 85%

something | Group of information 1 | Group of information 2
--- | --- | ---
Col 1 | Col 2 | Col 3 | Col 4 | Col 5
Student01 | Languages | male | 80 | 70
Student02 | Mathematics | male | 90 | 88
Student03 | Languages | female | 85 | 95

Col 1 | Col 2 | Col 3 | Col 4 | Col 5
--- | --- | --- | --- | ---
Student01 | Languages | male | 80 | 70
Student02 | Mathematics | male | 90 | 88
Student03 | Languages | female | 85 | 95